pub enum BitmapError {
NullReference,
PixelBufferSizeMismatch {
got: usize,
required: usize,
},
UnsupportedOperationForPixelFormat,
FailedPngWrite,
EmptyBitmap,
}Expand description
Errors can occure when creating Bitmaps
Variants
NullReference
The Ultralight library returned a null pointer.
PixelBufferSizeMismatch
The pixels passed to create the Bitmap does not match the required size.
UnsupportedOperationForPixelFormat
Tried to swap red and blue channels on an unsupported format.
FailedPngWrite
Could not write bitmap to PNG successfully.
EmptyBitmap
Could not create bitmap because its empty