Bitmap

Struct Bitmap 

pub struct Bitmap { /* private fields */ }
Ultralight Bitmap container.

Implementations

Source

impl Bitmap

pub fn create_empty(lib: Arc<Library>) -> Result<Self, BitmapError>

Create an empty Bitmap. No pixels will be allocated.

pub fn create( lib: Arc<Library>, width: usize, height: usize, format: BitmapFormat, ) -> Result<Self, BitmapError>

Create an aligned Bitmap with a certain configuration. Pixels will be allocated but not initialized.

Arguments
  • lib - The ultralight library.
  • width - The width of the bitmap.
  • height - The height of the bitmap.
  • format - The format of the bitmap.
pub fn create_from_pixels( lib: Arc<Library>, width: u32, height: u32, format: BitmapFormat, pixels: &[u8], ) -> Result<Self, BitmapError>

Create a Bitmap with existing pixels

Arguments
  • lib - The ultralight library.
  • width - The width of the bitmap.
  • height - The height of the bitmap.
  • format - The format of the bitmap.
  • pixels - The raw pixels of the bitmap.

The length of the pixels slice must be equal to width * height * format.bytes_per_pixel().

pub fn copy(&self) -> Result<Self, BitmapError>

Create a bitmap from a deep copy of another Bitmap.

Source

impl Bitmap

pub fn width(&self) -> u32

Get the width in pixels.

pub fn height(&self) -> u32

Get the height in pixels.

pub fn format(&self) -> BitmapFormat

Get the pixel format.

pub fn bpp(&self) -> u32

Get the number of bytes per pixel.

pub fn row_bytes(&self) -> u32

Get the number of bytes between each row of pixels.

This value is usually calculated as width() * bytes_per_pixel() (bpp) but it may be larger due to alignment rules in the allocator.

pub fn bytes_size(&self) -> usize

Get the size in bytes of the pixel buffer.

bytes_size is calculated as row_bytes() * height().

pub fn lock_pixels(&mut self) -> Option<PixelsGuard<'_>>

Lock the pixel buffer for reading/writing.

An RAII guard is returned that will unlock the buffer when dropped.

pub fn is_empty(&self) -> bool

Whether or not this bitmap is empty (no pixels allocated).

pub fn erase(&self)

Reset bitmap pixels to 0.

pub fn write_to_png<P: AsRef<Path>>(&self, path: P) -> Result<(), BitmapError>

Write bitmap to a PNG on disk.

pub fn swap_red_blue_channels(&self) -> Result<(), BitmapError>

This converts a BGRA bitmap to RGBA bitmap and vice-versa by swapping the red and blue channels.

Only valid if the format is BitmapFormat::BGRA8_UNORM_SRGB