OwnedBitmap

Struct OwnedBitmap 

pub struct OwnedBitmap { /* private fields */ }
A bitmap object that has an owned pixel buffer.

This is useful for using the raw pixels in any rust code without binding to the underlying C library.

To create an Ultralight bitmap, use OwnedBitmap::to_bitmap.

Implementations

Source

impl OwnedBitmap

pub fn from_bitmap(bitmap: &mut Bitmap) -> Option<Self>

Create an OwnedBitmap from a Bitmap.

This will result in copying all the pixels from the original bitmap.

pub fn to_bitmap(&self, lib: Arc<Library>) -> Result<Bitmap, BitmapError>

Create a Bitmap from an OwnedBitmap.

This is useful when we need to call Ultralight logic that require Bitmap.

This function will copy all the pixels from the owned bitmap.

pub fn width(&self) -> u32

Get the width in pixels.

pub fn height(&self) -> u32

Get the height in pixels.

pub fn format(&self) -> BitmapFormat

Get the pixel format.

pub fn bpp(&self) -> u32

Get the number of bytes per pixel.

pub fn row_bytes(&self) -> u32

Get the number of bytes between each row of pixels.

pub fn bytes_size(&self) -> usize

Get the size in bytes of the pixel buffer.

pub fn pixels(&self) -> Option<&[u8]>

Get the pixel buffer slice.

pub fn pixels_mut(&mut self) -> Option<&mut [u8]>

Get the mutable pixel buffer slice.

pub fn is_empty(&self) -> bool

Whether or not this bitmap is empty (no pixels allocated).