pub enum GamepadEventType {
Connected = 0,
Disconnected = 1,
}Expand description
The type of the GamepadEvent.
Variants
Connected = 0
This event type should be fired when a gamepad is connected
Note: You will need to previously declare the gamepad, its index, and details about
its axis and button layout via Renderer::set_gamepad_details
prior to calling Renderer::fire_gamepad_event.
Disconnected = 1
This event type should be fired when a gamepad is disconnected.