pub enum ScrollEventType {
ScrollByPixel = 0,
ScrollByPage = 1,
}Expand description
The type of the ScrollEvent.
Variants
ScrollByPixel = 0
The delta value is interpreted as number of pixels
ScrollByPage = 1
The delta value is interpreted as number of pages