GamepadButtonEvent

Struct GamepadButtonEvent 

pub struct GamepadButtonEvent { /* private fields */ }
Event representing a change in gamepad button state (eg, pressing a button on a gamepad).

See Renderer::fire_gamepad_button_event.

Implementations

Source

impl GamepadButtonEvent

pub fn new( lib: Arc<Library>, index: u32, button_index: u32, value: f64, ) -> Result<GamepadButtonEvent, CreationError>

Create a new GamepadButtonEvent.

Arguments
  • lib - The ultralight library.
  • index - The index of the gamepad, this should match the value previously set in Renderer::set_gamepad_details.
  • button_index - The index of the button whose value has changed. This value should be in the range previously set in Renderer::set_gamepad_details.
  • value - The new value of the axis. This value should be normalized to the range [-1.0, 1.0]. with any value greater than 0.0 to be considered “pressed”.