KeyEventCreationInfo

Struct KeyEventCreationInfo 

pub struct KeyEventCreationInfo<'a, 'b> {
    pub ty: KeyEventType,
    pub modifiers: KeyEventModifiers,
    pub virtual_key_code: VirtualKeyCode,
    pub native_key_code: i32,
    pub text: &'a str,
    pub unmodified_text: &'b str,
    pub is_keypad: bool,
    pub is_auto_repeat: bool,
    pub is_system_key: bool,
}
Wrapper around all arguments needed to create a KeyEvent.

Fields

ty: KeyEventType

The type of the event.

modifiers: KeyEventModifiers

The modifiers that were pressed with the key.

virtual_key_code: VirtualKeyCode

The virtual key-code associated with this keyboard event. This is either directly from the event (ie, WPARAM on Windows) or via a mapping function.

native_key_code: i32

The actual key-code generated by the platform. The DOM spec primarily uses Windows-equivalent codes (hence virtual_key_code above) but it helps to also specify the platform-specific key-code as well.

text: &'a str

The actual text generated by this keyboard event. This is usually only a single character.

unmodified_text: &'b str

The text generated by this keyboard event before all modifiers except shift are applied. This is used internally for working out shortcut keys. This is usually only a single character.

is_keypad: bool

Whether or not this is a keypad event.

is_auto_repeat: bool

Whether or not this was generated as the result of an auto-repeat (eg, holding down a key)

is_system_key: bool

Whether or not the pressed key is a “system key”. This is a Windows-only concept and should be “false” for all non-Windows platforms. For more information, see the following link: http://msdn.microsoft.com/en-us/library/ms646286(VS.85).aspx