pub struct MouseEvent { /* private fields */ }Expand description
A generic mouse event, that can be used to fire a key event in a
view by View::fire_mouse_event.
Implementations
Sourceimpl MouseEvent
impl MouseEvent
Sourcepub fn new(
lib: Arc<Library>,
ty: MouseEventType,
x: i32,
y: i32,
button: MouseButton,
) -> Result<MouseEvent, CreationError>
pub fn new( lib: Arc<Library>, ty: MouseEventType, x: i32, y: i32, button: MouseButton, ) -> Result<MouseEvent, CreationError>
Create a new MouseEvent.
Arguments
lib- The ultralight library.ty- The type of the event.x- The x-position of the mouse. relative to the view.y- The y-position of the mouse. relative to the view.button- The button that was pressed or released if any.