Ultralight custom gpu driver.
Ultralight allows to create a custom GPU driver to receive low level GPU commands and render them on custom Textures, which can be used to integrate to your game/application seamlessly.
There is an example C++ implementation for OpenGL, DirectX11, DirectX12
and Metal in the AppCore repository.
This library also have a custom GPU driver for glium.
Modules
Structs
- GpuState
- The GPU state description to be used when handling draw command.
(See
GpuCommand::DrawGeometry). - Index
Buffer - Index buffer. (See
GpuDriver::create_geometry). - Render
Buffer - RenderBuffer description. (See
GpuDriver::create_render_buffer). - Vertex
Buffer - Vertex buffer, the buffer is used for
quadorpathrendering based on theformat. (SeeGpuDriver::create_geometry).
Enums
- GpuCommand
- The GPU command to be executed.
- Shader
Type - Shader types, used by
GpuState::shader_type - Vertex
Buffer Format - Vertex buffer format types
Traits
- GpuDriver
GpuDrivertrait, dispatches GPU calls to the native driver.