Module image_source

Module image_source 

User-defined image source to display custom images on a web-page.

Modules

image_source_provider
Maps image sources to string identifiers.

Structs

ImageSource
User-defined image source to display custom images on a web-page.