pub struct Overlay { /* private fields */ }Available on crate features
appcore_linked or loaded only.Expand description
Web-content overlay. Displays a web-page within an area of the main window.
Each Overlay is essentially a View and an on-screen quad. You should
create the Overlay then load content into the underlying View.
Can be created with Window::create_overlay
or Window::create_overlay_with_view.
Implementations