set_filesystem

Function set_filesystem 

pub fn set_filesystem<T: FileSystem + Send + 'static>(
    lib: Arc<Library>,
    filesystem: T,
)
Set a custom FileSystem implementation.

The library uses this to load all file URLs (eg, file:///page.html).

You can provide the library with your own FileSystem implementation so that file assets are loaded from your own pipeline.

You should call this before Renderer::create or App::new.

Note: App::new will use the default platform file system if you never call this.

If you’re not using App::new, (eg, using Renderer::create) you can still use the default platform file system by calling platform::enable_platform_filesystem.