Logger

Trait Logger 

pub trait Logger {
    // Required method
    fn log_message(&mut self, log_level: LogLevel, message: String);
}
This can be used to log debug messages to the console or to a log file.

This is intended to be implemented by users and defined before creating the Renderer.

(See platform::set_logger)

Required Methods

fn log_message(&mut self, log_level: LogLevel, message: String)

Invoked when the library wants to print a message to the log.

Implementors