pub enum FontHinting {
Smooth = 0,
Normal = 1,
Monochrome = 2,
}Expand description
The font hinting algorithm.
Variants
Smooth = 0
Lighter hinting algorithm– glyphs are slightly fuzzier but better resemble their original shape. This is achieved by snapping glyphs to the pixel grid only vertically which better preserves inter-glyph spacing.
Normal = 1
Default hinting algorithm– offers a good balance between sharpness and shape at smaller font sizes.
Monochrome = 2
Strongest hinting algorithm– outputs only black/white glyphs. The result is usually unpleasant if the underlying TTF does not contain hints for this type of rendering.