User-defined image source to display custom images on a web-page.
Modules
- image_
source_ provider - Maps image sources to string identifiers.
Structs
- Image
Source - User-defined image source to display custom images on a web-page.
User-defined image source to display custom images on a web-page.