pub trait Logger {
// Required method
fn log_message(&mut self, log_level: LogLevel, message: String);
}Expand description
This can be used to log debug messages to the console or to a log file.
This is intended to be implemented by users and defined before creating the Renderer.
(See platform::set_logger)
Required Methods
Sourcefn log_message(&mut self, log_level: LogLevel, message: String)
fn log_message(&mut self, log_level: LogLevel, message: String)
Invoked when the library wants to print a message to the log.